==> haskell-text-conversions-0.3.1.1-163.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-K1Yt8b0G42m5WYfZmJLFVT
key:                  text-conversions-0.3.1.1-K1Yt8b0G42m5WYfZmJLFVT
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  397d1437569a7e0676ef39ea1573867b
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-K1Yt8b0G42m5WYfZmJLFVT
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-conversions-0.3.1.1-164-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-FiAyQC2JfI11GT7GIwm2Pu
key:                  text-conversions-0.3.1.1-FiAyQC2JfI11GT7GIwm2Pu
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  cae29c44da1f2b58baf138048ce1e0a7
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-FiAyQC2JfI11GT7GIwm2Pu
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
